@@ -55,18 +55,6 @@ function parseArrival(res, line, year) {
     return true;
 }
 
-function convertToBus(res) {
-    res['@type'] = 'BusReservation';
-    res.reservationFor['@type'] = 'BusTrip';
-    res.reservationFor.departureBusStop = res.reservationFor.departureStation;
-    res.reservationFor.departureBusStop['@type'] = 'BusStop';
-    res.reservationFor.arrivalBusStop = res.reservationFor.arrivalStation;
-    res.reservationFor.arrivalBusStop['@type'] = 'BusStop';
-    res.reservationFor.busName = res.reservationFor.trainName;
-    res.reservationFor.busNumber = res.reservationFor.trainNumber;
-    res.reservedTicket.ticketedSeat = undefined;
-}
-
 function parseLegs(text, year, compact) {
     var reservations = new Array();
     var lines = text.split('\n');
@@ -180,7 +168,8 @@ function parseTicket(text, uic918ticket) {
         reservations[i].reservationNumber = bookingRef[1];
 
         if (reservations[i].reservationFor.trainNumber && reservations[i].reservationFor.trainNumber.startsWith("Bus")) {
-            convertToBus(reservations[i]);
+            reservations[i] = JsonLd.trainToBusReservation(reservations[i]);
+            reservations[i].reservedTicket.ticketedSeat = undefined;
         }
     }
     return reservations;
@@ -230,7 +219,25 @@ function parsePdf(pdf, node, triggerNode) {
 
     var reservations = parseTicket(page.text, uic918ticket);
     for (var i = 0; i < reservations.length; ++i) {
-        reservations[i].reservedTicket.ticketToken = "aztecbin:" + Barcode.toBase64(triggerNode.content.rawData);
+        reservations[i].reservedTicket.ticketToken = "aztecbin:" + ByteArray.toBase64(triggerNode.content.rawData);
+        if (triggerNode.mimeType == "internal/uic9183") {
+            reservations[i].reservationFor.provider.identifier = "uic:" + triggerNode.content.carrierId;
+            const block = triggerNode.content.block("0080BL").findSubBlock("009")
+            if (block) {
+                const bc = block.content.match(/\d+-\d+-(.*)/)[1];
+                switch (bc) {
+                    case "49":
+                        reservations[i].programMembershipUsed.programName = "BahnCard 25";
+                        break;
+                    case "19":
+                    case "78":
+                        reservations[i].programMembershipUsed.programName = "BahnCard 50";
+                        break;
+                }
+            }
+        } else if (triggerNode.mimeType == "internal/vdv") {
+            reservations[i].reservationFor.provider.identifier = "vdv:" + triggerNode.content.operatorId;
+        }
         if (triggerNode.result.length > 0) {
             reservations[i].reservedTicket.name = triggerNode.result[0].reservedTicket.name;
             reservations[i].underName = triggerNode.result[0].underName;
@@ -254,3 +261,16 @@ function parseCancellation(html) {
     res.reservationFor = 1;
     return res;
 }
+
+function parseBahncard(code, node) {
+    if (code.ticketLayout.type != "RCT2" || !code.ticketLayout.text(0, 12, 40, 1).match(/BAHNCARD/i)) {
+        return;
+    }
+
+    var bc = JsonLd.newObject("ProgramMembership");
+    bc.programName = code.ticketLayout.text(1, 12, 40, 1);
+    bc.membershipNumber = code.ticketLayout.text(14, 11, 16, 1);
+    bc.member = node.result[0].underName;
+    bc.token = node.result[0].reservedTicket.ticketToken;
+    return bc.programName != undefined ? bc : undefined;
+}
